==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedHeaders An array of strings that will be used for inspecting headers that do not have a key that matches one of the provided values.
 * @property includedHeaders An array of strings that will be used for inspecting headers that have a key that matches one of the provided values.
 */
public data class WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern(
    public val all: WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPatternAll? = null,
    public val excludedHeaders: List<String>? = null,
    public val includedHeaders: List<String>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern):
            WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern =
            WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern(
                all = javaType.all().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPatternAll.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                excludedHeaders = javaType.excludedHeaders().map({ args0 -> args0 }),
                includedHeaders = javaType.includedHeaders().map({ args0 -> args0 }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedHeaders An array of strings that will be used for inspecting headers that do not have a key that matches one of the provided values.
 * @property includedHeaders An array of strings that will be used for inspecting headers that have a key that matches one of the provided values.
 */
public data class WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern(
    public val all: WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPatternAll? = null,
    public val excludedHeaders: List<String>? = null,
    public val includedHeaders: List<String>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern): WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern =
            WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern(
                all = javaType.all().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPatternAll.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                excludedHeaders = javaType.excludedHeaders().map({ args0 -> args0 }),
                includedHeaders = javaType.includedHeaders().map({ args0 -> args0 }),
            )
    }
}
